# `oscfar`

<p align=center>
<a target="_blank" href="https://www.python.org/downloads/" title="Python version"><img src="https://img.shields.io/badge/python-%3E=_3.8-green.svg"></a>
<a target="_blank" href="https://pypi.org/project/oscfar/" title="PyPI version"><img src="https://img.shields.io/pypi/v/oscfar?logo=pypi"></a>
</p>

OSCFAR (Order Statistic Constant False Alarm Rate) is a radar signal processing technique used for target detection. It adaptively estimates the noise or clutter power in the vicinity of a potential target and sets a detection threshold accordingly, maintaining a constant false alarm rate regardless of the background noise characteristics.

> Installation instruction are in [Getting Started](https://chujo58.github.io/oscfar/getstarted.html)
## Analytics
![Alt](https://repobeats.axiom.co/api/embed/664ddc1c4bc71b6bfaf29af87b32f32cc543f7a5.svg "Repobeats analytics image")
